#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Récupération des données
# 
# Ce notebook donne quelques exemples de codes qui permettent de récupérer les données utilisées par d'autres notebooks. Le module [actuariat_python](http://www.xavierdupre.fr/app/actuariat_python/helpsphinx/index.html) est implémenté avec Python 3. Pour les utilisateurs de Python 2.7, il suffira de recopier le code chaque fonction dans le notebook (suivre les liens insérés dans le notebook).

# In[1]:


get_ipython().run_line_magic('matplotlib', 'inline')
import matplotlib.pyplot as plt
plt.style.use('ggplot')
# le code qui suit n'est pas indispensable, il génère automatiquement un menu
# dans le notebook
from jyquickhelper import add_notebook_menu
add_notebook_menu()


# ### Population française janvier 2017
# 
# Les données sont disponibles sur le site de l'INSEE [Pyramide des âges au 1er janvier](https://www.insee.fr/fr/statistiques/1892086?sommaire=1912926). Elles sont disponibles au format Excel. Le format n'est pas le plus simple et il a le don d'être parfois illisible avec pandas. Le plus simple est de le convertir au format texte avec Excel.

# In[2]:


url = "https://www.insee.fr/fr/statistiques/fichier/1892086/pop-totale-france.xls"
url = "pop-totale-france.txt"
import pandas
df=pandas.read_csv(url, sep="\t", encoding="latin-1")
df.head(n=5)


# In[3]:


df=pandas.read_csv(url, sep="\t", encoding="latin-1", skiprows=3)
df.head(n=5)


# In[4]:


df.tail(n=5)


# La récupération de ces données est implémentée dans la fonction [population_france_year](http://www.xavierdupre.fr/app/actuariat_python/helpsphinx/actuariat_python/data/population.html#actuariat_python.data.population.population_france_year) :

# In[5]:


from actuariat_python.data import population_france_year
df = population_france_year()


# In[6]:


df.head(n=3)


# In[7]:


df.tail(n=3)


# D'après cette table, il y a plus de personnes âgées de 110 ans que de 109 ans. C'est dû au fait que la dernière ligne aggrège toutes les personnes âgées de plus de 110 ans.

# ### Table de mortalité 2000-2002 (France)
# 
# On utilise quelques raccourcis afin d'éviter d'y passer trop de temps. Les données sont fournis au format Excel à l'adresse : http://www.institutdesactuaires.com/gene/main.php?base=314. La fonction [table_mortalite_france_00_02](http://www.xavierdupre.fr/app/actuariat_python/helpsphinx/actuariat_python/data/population.html#actuariat_python.data.population.table_mortalite_france_00_02) permet de les récupérer.

# In[8]:


from actuariat_python.data import table_mortalite_france_00_02
df=table_mortalite_france_00_02()
df.head()


# In[9]:


df.plot(x="Age",y=["Homme", "Femme"],xlim=[0,100])


# ### Taux de fécondité (France)
# 
# On procède de même pour cette table avec la fonction [fecondite_france](http://www.xavierdupre.fr/app/actuariat_python/helpsphinx/actuariat_python/data/population.html#actuariat_python.data.population.fecondite_france). Source : [INSEE : Fécondité selon l'âge détaillé de la mère](http://www.insee.fr/fr/themes/tableau.asp?reg_id=0&ref_id=bilandemo2).

# In[10]:


from actuariat_python.data import fecondite_france
df=fecondite_france()
df.head()


# In[11]:


df.plot(x="age", y=["2005","2015"])


# ### Table de mortalité étendue 1960-2010
# 
# [table de mortalité de 1960 à 2010](http://www.data-publica.com/opendata/7098--population-et-conditions-sociales-table-de-mortalite-de-1960-a-2010) qu'on récupère à l'aide de la fonction [table_mortalite_euro_stat](http://www.xavierdupre.fr/app/actuariat_python/helpsphinx/actuariat_python/data/population.html#actuariat_python.data.population.table_mortalite_euro_stat).

# In[12]:


from actuariat_python.data import table_mortalite_euro_stat 
table_mortalite_euro_stat()


# In[13]:


import os
os.stat("mortalite.txt")


# In[14]:


import pandas
df = pandas.read_csv("mortalite.txt", sep="\t", encoding="utf8", low_memory=False)
df.head()


# In[15]:


df [ ((df.age=="Y60") | (df.age=="Y61")) & (df.annee == 2000) & (df.pays=="FR") & (df.genre=="F")]


# In[16]: